/**
 *  Copyright (c) 2015, Facebook, Inc.
 *  All rights reserved.
 *
 *  This source code is licensed under the license found in the
 *  LICENSE-examples file in the root directory of this source tree.
 */

'use strict';

var _inherits = require('babel-runtime/helpers/inherits')['default'];

var _classCallCheck = require('babel-runtime/helpers/class-call-check')['default'];

var _Object$keys = require('babel-runtime/core-js/object/keys')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

exports.__esModule = true;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

/**
 * DocExplorer
 *
 *
 * Props:
 *
 *
 */

var DocExplorer = (function (_React$Component) {
  _inherits(DocExplorer, _React$Component);

  function DocExplorer() {
    _classCallCheck(this, DocExplorer);

    _React$Component.call(this);

    this.EXPLORER_WIDTH = 400;
    this.currentlyInspectedType = null;
    this.state = {
      width: 'initial',
      expanded: false
    };

    this.startPage = 'Welcome to GraphQL Documentation Explorer!';
    this.content = '';
  }

  DocExplorer.prototype._renderTypeDefinitions = function _renderTypeDefinitions(type) {
    function renderField(field) {
      return _react2['default'].createElement(
        'div',
        null,
        _react2['default'].createElement(
          'a',
          { href: '#' },
          field.name
        ),
        _react2['default'].createElement(
          'span',
          null,
          ' : '
        ),
        _react2['default'].createElement(
          'a',
          { href: '#' },
          field.type.name
        )
      );
    }

    var fields = type.getFields();
    var fieldsJSX = [];
    _Object$keys(fields).forEach(function (fieldName) {
      fieldsJSX.push(renderField(fields[fieldName]));
    });

    return { fieldsJSX: fieldsJSX };
  };

  // TODO: This part could be optionalized

  DocExplorer.prototype._generateStartPage = function _generateStartPage(schema) {
    var queryType = schema.getQueryType();
    var mutationType = schema.getMutationType();
    var directives = schema.getDirectives();

    function renderDirectives() {
      return 'test';
    }

    var queryJSX = queryType ? _react2['default'].createElement(
      'div',
      { className: 'doc-call-def' },
      _react2['default'].createElement(
        'div',
        { className: 'doc-type-title' },
        'Query'
      ),
      this._renderTypeDefinitions(queryType)
    ) : '';

    var mutationJSX = mutationType ? _react2['default'].createElement(
      'div',
      { className: 'doc-call-def' },
      _react2['default'].createElement(
        'div',
        { className: 'doc-type-title' },
        'Mutation'
      ),
      this._renderTypeDefinitions(mutationType)
    ) : '';

    var directivesJSX = directives ? _react2['default'].createElement(
      'div',
      { className: 'doc-call-def' },
      _react2['default'].createElement(
        'div',
        { className: 'doc-type-title' },
        'Directive'
      ),
      renderDirectives(directives)
    ) : '';

    return _react2['default'].createElement(
      'div',
      { className: 'doc-table-of-contents' },
      queryJSX,
      mutationJSX,
      directivesJSX
    );
  };

  DocExplorer.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    if (nextProps.schema && nextProps.schema !== this.props.schema) {
      this.startPage = this._generateStartPage(nextProps.schema);
    }

    if (nextProps.typeName !== this.props.typeName) {
      var typeName = nextProps.typeName;
      if (typeName.endsWith('!')) {
        typeName = typeName.slice(0, typeName.length - 1);
      }
      this.currentlyInspectedType = this.props.schema.getTypeMap[typeName];

      this.setState({
        width: this.EXPLORER_WIDTH,
        expanded: true
      });
    }
  };

  DocExplorer.prototype._onToggleBtnClick = function _onToggleBtnClick() {
    this.setState({
      width: this.state.expanded ? 'initial' : this.EXPLORER_WIDTH,
      expanded: !this.state.expanded
    });
  };

  DocExplorer.prototype.render = function render() {
    if (this.state.expanded) {
      this.content = this.currentlyInspectedType ? this.currentlyInspectedType.description || 'Type description not found.' : this.startPage;
    } else {
      this.content = '';
    }

    return _react2['default'].createElement(
      'div',
      { className: 'doc-explorer', style: { width: this.state.width } },
      _react2['default'].createElement(
        'div',
        { className: 'doc-explorer-title-bar' },
        _react2['default'].createElement(
          'button',
          {
            className: 'doc-explorer-toggle-button',
            onClick: this._onToggleBtnClick.bind(this)
          },
          this.state.expanded ? 'Hide' : 'Docs'
        ),
        _react2['default'].createElement(
          'div',
          { className: 'doc-explorer-title',
            style: { display: this.state.expanded ? 'block' : 'none' }
          },
          'Documentation Explorer'
        )
      ),
      _react2['default'].createElement(
        'div',
        { className: 'doc-explorer-contents' },
        this.content
      )
    );
  };

  return DocExplorer;
})(_react2['default'].Component);

exports.DocExplorer = DocExplorer;